netapp_ontap.resources.switch API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.switch`

Copyright © 2020 NetApp Inc. All rights reserved.

## Overview

This API can be used to get information about the ethernet switches used for cluster and/or storage networks. This API support GET and PATCH calls. The GET operation returns a list of discovered switches with status and configuration information. The PATCH can be used to modify state of the switch.

## Examples

### Retrieving the ethernet switches for a cluster

The following example retrieves the ONTAP switches from the cluster. Note that if the fields=* parameter is not specified, the fields snmp.version, snmp.credential, model, sw-version, reason, version-source, monitoring.enable, monitoring.subsystem.type and monitoring.subsystem.poll_interval are not returned. Filters can be added on the fields to limit the results.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Switch

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(Switch.get_collection()))

Try it out

    [
        Switch(
            {
                "snmp": {"version": "snmpv2c", "user": "cshm1!"},
                "serial_number": "Unknown",
                "discovered": True,
                "_links": {
                    "self": {
                        "href": "/api/network/ethernet/switches/RTP-CS01-510R11%28FOC22092K12%29"
                    }
                },
                "version": "Cisco Nexus Operating System (NX-OS) Software, Version 9.2(3)",
                "model": "NX3232C",
                "monitoring": {"reason": "None", "monitored": True},
                "name": "RTP-CS01-510R11(FOC22092K12)",
                "address": "172.26.207.77",
                "network": "cluster",
            }
        ),
        Switch(
            {
                "snmp": {"version": "snmpv2c", "user": "cshm1!"},
                "serial_number": "FOC22373C3P",
                "discovered": True,
                "_links": {
                    "self": {
                        "href": "/api/network/ethernet/switches/RTP-CS01-510R12%28FOC22373C3P%29"
                    }
                },
                "version": "Cisco Nexus Operating System (NX-OS) Software, Version 9.2(3)",
                "model": "NX3232C",
                "monitoring": {"reason": "None", "monitored": True},
                "name": "RTP-CS01-510R12(FOC22373C3P)",
                "address": "172.26.207.82",
                "network": "cluster",
            }
        ),
        Switch(
            {
                "snmp": {"version": "snmpv2c", "user": "cshm1!"},
                "serial_number": "FOC22170DFR",
                "discovered": True,
                "_links": {
                    "self": {
                        "href": "/api/network/ethernet/switches/RTP-SS01-510R10%28FOC22170DFR%29"
                    }
                },
                "version": "Cisco Nexus Operating System (NX-OS) Software, Version 9.3(3)",
                "model": "NX3232C",
                "monitoring": {"reason": "None", "monitored": True},
                "name": "RTP-SS01-510R10(FOC22170DFR)",
                "address": "172.26.207.65",
                "network": "storage",
            }
        ),
        Switch(
            {
                "snmp": {"version": "snmpv2c", "user": "cshm1!"},
                "serial_number": "FOC22131U6T",
                "discovered": True,
                "_links": {
                    "self": {
                        "href": "/api/network/ethernet/switches/RTP-SS02-510R10%28FOC22131U6T%29"
                    }
                },
                "version": "Cisco Nexus Operating System (NX-OS) Software, Version 9.3(3)",
                "model": "NX3232C",
                "monitoring": {"reason": "None", "monitored": True},
                "name": "RTP-SS02-510R10(FOC22131U6T)",
                "address": "172.26.207.66",
                "network": "storage",
            }
        ),
    ]

### Retrieving an ethernet switch for a cluster

The following example retrieves a single switch by the switchname using the API. ```python from netapp_ontap import HostConnection from netapp_ontap.resources import Switch

with HostConnection("", username="admin", password="password", verify=False): resource = Switch(name="RTP-SS02-510R10(FOC22131U6T") resource.get() print(resource)

    <div class="try_it_out">
    <input id="example1_try_it_out" type="checkbox", class="try_it_out_check">
    <label for="example1_try_it_out" class="try_it_out_button">Try it out</label>
    <div id="example1_result" class="try_it_out_content">

Switch( { "snmp": {"version": "snmpv2c", "user": "cshm1!"}, "serial_number": "FOC22131U6T", "discovered": True, "_links": { "self": { "href": "/api/network/ethernet/switches/RTP-SS02-510R10(FOC22131U6T)" } }, "version": "Cisco Nexus Operating System (NX-OS) Software, Version 9.3(3)", "model": "NX3232C", "monitoring": {"reason": "None", "monitored": True}, "name": "RTP-SS02-510R10(FOC22131U6T)", "address": "172.26.207.66", "network": "storage", } )

    </div>
    </div>

    ---
    ### Configuring a switch
    The following example configures SNMP credential and version on a switch.
    ```python
    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Switch

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Switch(name="sconqa-corduroyl-03")
        resource.snmp.version = "snmpv2c"
        resource.snmp.user = "cshm1!"
        resource.patch()

## Classes

`class Switch (*args, **kwargs)`

  Ethernet Switch REST API

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection(*args, connection: HostConnection = None, **kwargs) -> int`

    Retrieves the ethernet switches attached to the chassis.

    ### Related ONTAP commands

    - `system switch ethernet show`

    ### Learn more

    - `DOC /network/ethernet/switches`

    Fetch a count of all objects of this type from the host.

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def find(*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves the ethernet switches attached to the chassis.

    ### Related ONTAP commands

    - `system switch ethernet show`

    ### Learn more

    - `DOC /network/ethernet/switches`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection(*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> typing.Iterable`

    Retrieves the ethernet switches attached to the chassis.

    ### Related ONTAP commands

    - `system switch ethernet show`

    ### Learn more

    - `DOC /network/ethernet/switches`

    Fetch a list of all objects of this type from the host.

    This is a lazy fetch, making API calls only as necessary when the result of this call is iterated over. For instance, if max_records is set to 5, then iterating over the collection causes an API call to be sent to the server once for every 5 records. If the client stops iterating before getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection(body: dict, *args, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Update Ethernet Switch REST API

    ### Learn more

    - `DOC /network/ethernet/switches`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves the details of an ethernet switch.

    ### Related ONTAP commands

    - `system switch ethernet show`

    ### Learn more

    - `DOC /network/ethernet/switches`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def patch(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Update Ethernet Switch REST API

    ### Learn more

    - `DOC /network/ethernet/switches`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class SwitchSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the Switch object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `address GET POST PATCH`

    IP Address.

  `discovered GET`

    Discovered By ONTAP CDP/LLDP

  `links GET`

    The links field of the switch.

  `model GET`

    Model Number.

  `monitoring GET POST PATCH`

    The monitoring field of the switch.

  `name GET`

    Name.

  `network GET`

    Switch Network.

    Valid choices:

    - cluster
    - management
    - storage
  `serial_number GET`

    Serial Number.

  `snmp GET POST PATCH`

    The snmp field of the switch.

  `version GET`

    Software Version.